act.plotting.HistogramDisplay
=============================

.. currentmodule:: act.plotting

.. autoclass:: HistogramDisplay

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HistogramDisplay.__init__
      ~HistogramDisplay.add_colorbar
      ~HistogramDisplay.add_subplots
      ~HistogramDisplay.assign_to_figure_axis
      ~HistogramDisplay.plot_heatmap
      ~HistogramDisplay.plot_size_distribution
      ~HistogramDisplay.plot_stacked_bar_graph
      ~HistogramDisplay.plot_stairstep_graph
      ~HistogramDisplay.put_display_in_subplot
      ~HistogramDisplay.set_xrng
      ~HistogramDisplay.set_yrng
   
   

   
   
   